@@ -3,7 +3,7 @@ package GeoIP2::Database::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '2.003004';
+our $VERSION = '2.003005';
 
 use Moo;
 
@@ -11,6 +11,7 @@ use Data::Validate::IP 0.24
     qw( is_ipv4 is_ipv6 is_private_ipv4 is_private_ipv6 );
 use GeoIP2::Error::Generic;
 use GeoIP2::Error::IPAddressNotFound;
+use GeoIP2::Model::ASN;
 use GeoIP2::Model::AnonymousIP;
 use GeoIP2::Model::City;
 use GeoIP2::Model::ConnectionType;
@@ -108,6 +109,16 @@ sub _model_for_address {
     );
 }
 
+sub asn {
+    my $self = shift;
+    return $self->_model_for_address(
+        'ASN',
+        type_check => qr/^GeoLite2-ASN$/,
+        is_flat    => 1,
+        @_
+    );
+}
+
 sub city {
     my $self = shift;
     return $self->_model_for_address(
@@ -192,7 +203,7 @@ GeoIP2::Database::Reader - Perl API for GeoIP2 databases
 
 =head1 VERSION
 
-version 2.003004
+version 2.003005
 
 =head1 SYNOPSIS
 
@@ -310,6 +321,10 @@ address.
 
 =back
 
+=head2 $reader->asn()
+
+This method returns a L<GeoIP2::Model::ASN> object.
+
 =head2 $reader->connection_type()
 
 This method returns a L<GeoIP2::Model::ConnectionType> object.
